package cn.com.infosec.asn1.ocsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.X509Extensions;

public class SingleResponse extends ASN1Encodable {
   private CertID certID;
   private CertStatus certStatus;
   private DERGeneralizedTime thisUpdate;
   private DERGeneralizedTime nextUpdate;
   private X509Extensions singleExtensions;

   public SingleResponse(CertID certID, CertStatus certStatus, DERGeneralizedTime thisUpdate, DERGeneralizedTime nextUpdate, X509Extensions singleExtensions) {
      this.certID = certID;
      this.certStatus = certStatus;
      this.thisUpdate = thisUpdate;
      this.nextUpdate = nextUpdate;
      this.singleExtensions = singleExtensions;
   }

   public SingleResponse(ASN1Sequence seq) {
      this.certID = CertID.getInstance(seq.getObjectAt(0));
      this.certStatus = CertStatus.getInstance(seq.getObjectAt(1));
      this.thisUpdate = (DERGeneralizedTime)seq.getObjectAt(2);
      if (seq.size() > 4) {
         this.nextUpdate = DERGeneralizedTime.getInstance((ASN1TaggedObject)seq.getObjectAt(3), true);
         this.singleExtensions = X509Extensions.getInstance((ASN1TaggedObject)seq.getObjectAt(4), true);
      } else if (seq.size() > 3) {
         ASN1TaggedObject seq1;
         if ((seq1 = (ASN1TaggedObject)seq.getObjectAt(3)).getTagNo() == 0) {
            this.nextUpdate = DERGeneralizedTime.getInstance(seq1, true);
         } else {
            this.singleExtensions = X509Extensions.getInstance(seq1, true);
         }
      }

   }

   public static SingleResponse getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static SingleResponse getInstance(Object obj) {
      if (obj != null && !(obj instanceof SingleResponse)) {
         if (obj instanceof ASN1Sequence) {
            return new SingleResponse((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (SingleResponse)obj;
      }
   }

   public CertID getCertID() {
      return this.certID;
   }

   public CertStatus getCertStatus() {
      return this.certStatus;
   }

   public DERGeneralizedTime getThisUpdate() {
      return this.thisUpdate;
   }

   public DERGeneralizedTime getNextUpdate() {
      return this.nextUpdate;
   }

   public X509Extensions getSingleExtensions() {
      return this.singleExtensions;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.certID);
      var1.add(this.certStatus);
      var10001.add(this.thisUpdate);
      DERGeneralizedTime var2;
      if ((var2 = this.nextUpdate) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(true, 0, var2);
         var1.add(var3);
      }

      X509Extensions var4;
      if ((var4 = this.singleExtensions) != null) {
         DERTaggedObject var5;
         var5 = new DERTaggedObject.<init>(true, 1, var4);
         var1.add(var5);
      }

      return new DERSequence(var1);
   }
}
